Index: bp-friends.php
===================================================================
--- bp-friends.php	(revision 2904)
+++ bp-friends.php	(working copy)
@@ -112,14 +112,14 @@
 		<tr>
 			<td></td>
 			<td><?php _e( 'A member sends you a friendship request', 'buddypress' ) ?></td>
-			<td class="yes"><input type="radio" name="notifications[notification_friends_friendship_request]" value="yes" <?php if ( !get_usermeta( $current_user->id,'notification_friends_friendship_request') || 'yes' == get_usermeta( $current_user->id,'notification_friends_friendship_request') ) { ?>checked="checked" <?php } ?>/></td>
-			<td class="no"><input type="radio" name="notifications[notification_friends_friendship_request]" value="no" <?php if ( get_usermeta( $current_user->id,'notification_friends_friendship_request') == 'no' ) { ?>checked="checked" <?php } ?>/></td>
+			<td class="yes"><input type="radio" name="notifications[notification_friends_friendship_request]" value="yes" <?php if ( !get_user_meta( $current_user->id, 'notification_friends_friendship_request', true ) || 'yes' == get_user_meta( $current_user->id, 'notification_friends_friendship_request', true ) ) { ?>checked="checked" <?php } ?>/></td>
+			<td class="no"><input type="radio" name="notifications[notification_friends_friendship_request]" value="no" <?php if ( get_user_meta( $current_user->id, 'notification_friends_friendship_request', true ) == 'no' ) { ?>checked="checked" <?php } ?>/></td>
 		</tr>
 		<tr>
 			<td></td>
 			<td><?php _e( 'A member accepts your friendship request', 'buddypress' ) ?></td>
-			<td class="yes"><input type="radio" name="notifications[notification_friends_friendship_accepted]" value="yes" <?php if ( !get_usermeta( $current_user->id,'notification_friends_friendship_accepted') || 'yes' == get_usermeta( $current_user->id,'notification_friends_friendship_accepted') ) { ?>checked="checked" <?php } ?>/></td>
-			<td class="no"><input type="radio" name="notifications[notification_friends_friendship_accepted]" value="no" <?php if ( 'no' == get_usermeta( $current_user->id,'notification_friends_friendship_accepted') ) { ?>checked="checked" <?php } ?>/></td>
+			<td class="yes"><input type="radio" name="notifications[notification_friends_friendship_accepted]" value="yes" <?php if ( !get_user_meta( $current_user->id, 'notification_friends_friendship_accepted', true ) || 'yes' == get_user_meta( $current_user->id, 'notification_friends_friendship_accepted', true ) ) { ?>checked="checked" <?php } ?>/></td>
+			<td class="no"><input type="radio" name="notifications[notification_friends_friendship_accepted]" value="no" <?php if ( 'no' == get_user_meta( $current_user->id, 'notification_friends_friendship_accepted', true ) ) { ?>checked="checked" <?php } ?>/></td>
 		</tr>
 
 		<?php do_action( 'friends_screen_notification_settings' ); ?>
@@ -443,7 +443,7 @@
 		$user_id = ( $bp->displayed_user->id ) ? $bp->displayed_user->id : $bp->loggedin_user->id;
 
 	if ( !$count = wp_cache_get( 'bp_total_friend_count_' . $user_id, 'bp' ) ) {
-		$count = get_usermeta( $user_id, 'total_friend_count' );
+		$count = get_user_meta( $user_id, 'total_friend_count', true );
 		if ( empty( $count ) ) $count = 0;
 		wp_cache_set( 'bp_total_friend_count_' . $user_id, $count, 'bp' );
 	}
@@ -546,11 +546,11 @@
 
 function friends_update_friend_totals( $initiator_user_id, $friend_user_id, $status = 'add' ) {
 	if ( 'add' == $status ) {
-		update_usermeta( $initiator_user_id, 'total_friend_count', (int)get_usermeta( $initiator_user_id, 'total_friend_count' ) + 1 );
-		update_usermeta( $friend_user_id, 'total_friend_count', (int)get_usermeta( $friend_user_id, 'total_friend_count' ) + 1 );
+		update_user_meta( $initiator_user_id, 'total_friend_count', (int)get_user_meta( $initiator_user_id, 'total_friend_count', true ) + 1 );
+		update_user_meta( $friend_user_id, 'total_friend_count', (int)get_user_meta( $friend_user_id, 'total_friend_count', true ) + 1 );
 	} else {
-		update_usermeta( $initiator_user_id, 'total_friend_count', (int)get_usermeta( $initiator_user_id, 'total_friend_count' ) - 1 );
-		update_usermeta( $friend_user_id, 'total_friend_count', (int)get_usermeta( $friend_user_id, 'total_friend_count' ) - 1 );
+		update_user_meta( $initiator_user_id, 'total_friend_count', (int)get_user_meta( $initiator_user_id, 'total_friend_count', true ) - 1 );
+		update_user_meta( $friend_user_id, 'total_friend_count', (int)get_user_meta( $friend_user_id, 'total_friend_count', true ) - 1 );
 	}
 }
 
@@ -558,7 +558,7 @@
 	BP_Friends_Friendship::delete_all_for_user($user_id);
 
 	/* Remove usermeta */
-	delete_usermeta( $user_id, 'total_friend_count' );
+	delete_user_meta( $user_id, 'total_friend_count' );
 
 	/* Remove friendship requests FROM user */
 	bp_core_delete_notifications_from_user( $user_id, $bp->friends->id, 'friendship_request' );
Index: bp-activity.php
===================================================================
--- bp-activity.php	(revision 2904)
+++ bp-activity.php	(working copy)
@@ -193,14 +193,14 @@
 		<tr>
 			<td></td>
 			<td><?php printf( __( 'A member mentions you in an update using "@%s"', 'buddypress' ), bp_core_get_username( $bp->loggedin_user->id, $bp->loggedin_user->userdata->user_nicename, $bp->loggedin_user->userdata->user_login ) ) ?></td>
-			<td class="yes"><input type="radio" name="notifications[notification_activity_new_mention]" value="yes" <?php if ( !get_usermeta( $bp->loggedin_user->id, 'notification_activity_new_mention' ) || 'yes' == get_usermeta( $bp->loggedin_user->id, 'notification_activity_new_mention' ) ) { ?>checked="checked" <?php } ?>/></td>
-			<td class="no"><input type="radio" name="notifications[notification_activity_new_mention]" value="no" <?php if ( 'no' == get_usermeta( $bp->loggedin_user->id, 'notification_activity_new_mention' ) ) { ?>checked="checked" <?php } ?>/></td>
+			<td class="yes"><input type="radio" name="notifications[notification_activity_new_mention]" value="yes" <?php if ( !get_user_meta( $bp->loggedin_user->id, 'notification_activity_new_mention', true ) || 'yes' == get_user_meta( $bp->loggedin_user->id, 'notification_activity_new_mention', true ) ) { ?>checked="checked" <?php } ?>/></td>
+			<td class="no"><input type="radio" name="notifications[notification_activity_new_mention]" value="no" <?php if ( 'no' == get_user_meta( $bp->loggedin_user->id, 'notification_activity_new_mention', true ) ) { ?>checked="checked" <?php } ?>/></td>
 		</tr>
 		<tr>
 			<td></td>
 			<td><?php printf( __( "A member replies to an update or comment you've posted", 'buddypress' ), $current_user->user_login ) ?></td>
-			<td class="yes"><input type="radio" name="notifications[notification_activity_new_reply]" value="yes" <?php if ( !get_usermeta( $bp->loggedin_user->id, 'notification_activity_new_reply' ) || 'yes' == get_usermeta( $bp->loggedin_user->id, 'notification_activity_new_reply' ) ) { ?>checked="checked" <?php } ?>/></td>
-			<td class="no"><input type="radio" name="notifications[notification_activity_new_reply]" value="no" <?php if ( 'no' == get_usermeta( $bp->loggedin_user->id, 'notification_activity_new_reply' ) ) { ?>checked="checked" <?php } ?>/></td>
+			<td class="yes"><input type="radio" name="notifications[notification_activity_new_reply]" value="yes" <?php if ( !get_user_meta( $bp->loggedin_user->id, 'notification_activity_new_reply', true ) || 'yes' == get_user_meta( $bp->loggedin_user->id, 'notification_activity_new_reply', true ) ) { ?>checked="checked" <?php } ?>/></td>
+			<td class="no"><input type="radio" name="notifications[notification_activity_new_reply]" value="no" <?php if ( 'no' == get_user_meta( $bp->loggedin_user->id, 'notification_activity_new_reply', true ) ) { ?>checked="checked" <?php } ?>/></td>
 		</tr>
 
 		<?php do_action( 'bp_activity_screen_notification_settings' ) ?>
@@ -627,7 +627,7 @@
 	) );
 
 	/* Add this update to the "latest update" usermeta so it can be fetched anywhere. */
-	update_usermeta( $bp->loggedin_user->id, 'bp_latest_update', array( 'id' => $activity_id, 'content' => wp_filter_kses( $content ) ) );
+	update_user_meta( $bp->loggedin_user->id, 'bp_latest_update', array( 'id' => $activity_id, 'content' => wp_filter_kses( $content ) ) );
 
  	/* Require the notifications code so email notifications can be set on the 'bp_activity_posted_update' action. */
 	require_once( BP_PLUGIN_DIR . '/bp-activity/bp-activity-notifications.php' );
@@ -754,10 +754,10 @@
 	else
 		$user_id = $args['user_id'];
 
-	$latest_update = get_usermeta( $user_id, 'bp_latest_update' );
+	$latest_update = get_user_meta( $user_id, 'bp_latest_update', true );
 	if ( !empty( $latest_update ) ) {
 		if ( in_array( (int)$latest_update['id'], (array)$activity_ids_deleted ) )
-			delete_usermeta( $user_id, 'bp_latest_update' );
+			delete_user_meta( $user_id, 'bp_latest_update' );
 	}
 
 	do_action( 'bp_activity_delete', $args );
@@ -908,14 +908,14 @@
 }
 
 function bp_activity_get_user_favorites( $user_id ) {
-	$my_favs = maybe_unserialize( get_usermeta( $user_id, 'bp_favorite_activities' ) );
+	$my_favs = get_user_meta( $user_id, 'bp_favorite_activities', true );
 	$existing_favs = bp_activity_get_specific( array( 'activity_ids' => $my_favs ) );
 
 	foreach( (array)$existing_favs['activities'] as $fav )
 		$new_favs[] = $fav->id;
 
 	$new_favs = array_unique( (array)$new_favs );
-	update_usermeta( $user_id, 'bp_favorite_activities', $new_favs );
+	update_user_meta( $user_id, 'bp_favorite_activities', $new_favs );
 
 	return apply_filters( 'bp_activity_get_user_favorites', $new_favs );
 }
@@ -927,7 +927,7 @@
 		$user_id = $bp->loggedin_user->id;
 
 	/* Update the user's personal favorites */
-	$my_favs = maybe_unserialize( get_usermeta( $bp->loggedin_user->id, 'bp_favorite_activities' ) );
+	$my_favs = get_user_meta( $bp->loggedin_user->id, 'bp_favorite_activities', true );
 	$my_favs[] = $activity_id;
 
 	/* Update the total number of users who have favorited this activity */
@@ -938,7 +938,7 @@
 	else
 		$fav_count = 1;
 
-	update_usermeta( $bp->loggedin_user->id, 'bp_favorite_activities', $my_favs );
+	update_user_meta( $bp->loggedin_user->id, 'bp_favorite_activities', $my_favs );
 	bp_activity_update_meta( $activity_id, 'favorite_count', $fav_count );
 
 	do_action( 'bp_activity_add_user_favorite', $activity_id, $user_id );
@@ -953,7 +953,7 @@
 		$user_id = $bp->loggedin_user->id;
 
 	/* Remove the fav from the user's favs */
-	$my_favs = maybe_unserialize( get_usermeta( $user_id, 'bp_favorite_activities' ) );
+	$my_favs = get_user_meta( $user_id, 'bp_favorite_activities', true );
 	$my_favs = array_flip( (array) $my_favs );
 	unset( $my_favs[$activity_id] );
 	$my_favs = array_unique( array_flip( $my_favs ) );
@@ -966,7 +966,7 @@
 		bp_activity_update_meta( $activity_id, 'favorite_count', $fav_count );
 	}
 
-	update_usermeta( $user_id, 'bp_favorite_activities', $my_favs );
+	update_user_meta( $user_id, 'bp_favorite_activities', $my_favs );
 
 	do_action( 'bp_activity_remove_user_favorite', $activity_id, $user_id );
 
@@ -1088,8 +1088,8 @@
 	bp_activity_delete( array( 'user_id' => $user_id ) );
 
 	// Remove any usermeta
-	delete_usermeta( $user_id, 'bp_latest_update' );
-	delete_usermeta( $user_id, 'bp_favorite_activities' );
+	delete_user_meta( $user_id, 'bp_latest_update' );
+	delete_user_meta( $user_id, 'bp_favorite_activities' );
 
 	do_action( 'bp_activity_remove_data', $user_id );
 }
Index: bp-themes/bp-default/_inc/ajax.php
===================================================================
--- bp-themes/bp-default/_inc/ajax.php	(revision 2904)
+++ bp-themes/bp-default/_inc/ajax.php	(working copy)
@@ -92,7 +92,7 @@
 			break;
 		case 'mentions':
 			$feed_url = $bp->loggedin_user->domain . BP_ACTIVITY_SLUG . '/mentions/feed/';
-			delete_usermeta( $bp->loggedin_user->id, 'bp_new_mention_count' );
+			delete_user_meta( $bp->loggedin_user->id, 'bp_new_mention_count' );
 			break;
 	}
 
@@ -442,11 +442,11 @@
 	if ( !isset( $_POST['notice_id'] ) ) {
 		echo "-1<div id='message' class='error'><p>" . __('There was a problem closing the notice.', 'buddypress') . '</p></div>';
 	} else {
-		$notice_ids = get_usermeta( $userdata->ID, 'closed_notices' );
+		$notice_ids = get_user_meta( $userdata->ID, 'closed_notices', true );
 
 		$notice_ids[] = (int) $_POST['notice_id'];
 
-		update_usermeta( $userdata->ID, 'closed_notices', $notice_ids );
+		update_user_meta( $userdata->ID, 'closed_notices', $notice_ids );
 	}
 }
 add_action( 'wp_ajax_messages_close_notice', 'bp_dtheme_ajax_close_notice' );
Index: bp-xprofile/bp-xprofile-templatetags.php
===================================================================
--- bp-xprofile/bp-xprofile-templatetags.php	(revision 2904)
+++ bp-xprofile/bp-xprofile-templatetags.php	(working copy)
@@ -637,7 +637,7 @@
 	function bp_get_profile_last_updated() {
 		global $bp;
 
-		$last_updated = get_usermeta( $bp->displayed_user->id, 'profile_last_updated' );
+		$last_updated = get_user_meta( $bp->displayed_user->id, 'profile_last_updated', true );
 
 		if ( $last_updated )
 			return apply_filters( 'bp_get_profile_last_updated', sprintf( __('Profile updated %s ago', 'buddypress'), bp_core_time_since( strtotime( $last_updated ) ) ) );
Index: bp-core/bp-core-signup.php
===================================================================
--- bp-core/bp-core-signup.php	(revision 2904)
+++ bp-core/bp-core-signup.php	(working copy)
@@ -360,7 +360,7 @@
 	 */
 	if ( !bp_core_is_multisite() ) {
 		$activation_key = wp_hash( $user_id );
-		update_usermeta( $user_id, 'activation_key', $activation_key );
+		update_user_meta( $user_id, 'activation_key', $activation_key );
 		bp_core_signup_send_validation_email( $user_id, $user_email, $activation_key );
 	}
 
@@ -422,14 +422,14 @@
 		wp_new_user_notification( $user_id );
 
 		/* Remove the activation key meta */
-		delete_usermeta( $user_id, 'activation_key' );
+		delete_user_meta( $user_id, 'activation_key' );
 	}
 
 	/* Update the user_url and display_name */
 	wp_update_user( array( 'ID' => $user_id, 'user_url' => bp_core_get_user_domain( $user_id, sanitize_title( $user_login ), $user_login ), 'display_name' => bp_core_get_user_displayname( $user_id ) ) );
 
 	/* Add a last active entry */
-	update_usermeta( $user_id, 'last_activity', gmdate( "Y-m-d H:i:s" ) );
+	update_user_meta( $user_id, 'last_activity', gmdate( "Y-m-d H:i:s" ) );
 
 	/* Set the password on multisite installs */
 	if ( bp_core_is_multisite() && !empty( $user['meta']['password'] ) )
@@ -472,16 +472,16 @@
 		return false;
 
 	/* Add a last active entry */
-	update_usermeta( $user_id, 'last_activity', gmdate( "Y-m-d H:i:s" ) );
+	update_user_meta( $user_id, 'last_activity', gmdate( "Y-m-d H:i:s" ) );
 
 	/* Add the user's fullname to Xprofile */
 	if ( function_exists( 'xprofile_set_field_data' ) ) {
-		$firstname = get_usermeta( $user_id, 'first_name' );
-		$lastname = ' ' . get_usermeta( $user_id, 'last_name' );
+		$firstname = get_user_meta( $user_id, 'first_name', true );
+		$lastname = ' ' . get_user_meta( $user_id, 'last_name', true );
 		$name = $firstname . $lastname;
 
 		if ( empty( $name ) || ' ' == $name )
-			$name = get_usermeta( $user_id, 'nickname' );
+			$name = get_user_meta( $user_id, 'nickname', true );
 
 		xprofile_set_field_data( 1, $user_id, $name );
 	}
Index: bp-core/bp-core-templatetags.php
===================================================================
--- bp-core/bp-core-templatetags.php	(revision 2904)
+++ bp-core/bp-core-templatetags.php	(working copy)
@@ -677,7 +677,7 @@
 	if ( !$user_id )
 		$user_id = $bp->displayed_user->id;
 
-	$last_activity = bp_core_get_last_activity( get_usermeta( $user_id, 'last_activity' ), __('active %s ago', 'buddypress') );
+	$last_activity = bp_core_get_last_activity( get_user_meta( $user_id, 'last_activity', true ), __('active %s ago', 'buddypress') );
 
 	if ( $echo )
 		echo apply_filters( 'bp_last_activity', $last_activity );
Index: bp-core/bp-core-settings.php
===================================================================
--- bp-core/bp-core-settings.php	(revision 2904)
+++ bp-core/bp-core-settings.php	(working copy)
@@ -114,7 +114,7 @@
 
 		if ( $_POST['notifications'] ) {
 			foreach ( (array)$_POST['notifications'] as $key => $value ) {
-				update_usermeta( (int)$current_user->id, $key, $value );
+				update_user_meta( (int)$current_user->id, $key, $value );
 			}
 		}
 
Index: bp-friends/bp-friends-notifications.php
===================================================================
--- bp-friends/bp-friends-notifications.php	(revision 2904)
+++ bp-friends/bp-friends-notifications.php	(working copy)
@@ -5,7 +5,7 @@
 
 	$initiator_name = bp_core_get_user_displayname( $initiator_id );
 
-	if ( 'no' == get_usermeta( (int)$friend_id, 'notification_friends_friendship_request' ) )
+	if ( 'no' == get_user_meta( (int)$friend_id, 'notification_friends_friendship_request', true ) )
 		return false;
 
 	$ud = get_userdata( $friend_id );
@@ -47,7 +47,7 @@
 
 	$friend_name = bp_core_get_user_displayname( $friend_id );
 
-	if ( 'no' == get_usermeta( (int)$initiator_id, 'notification_friends_friendship_accepted' ) )
+	if ( 'no' == get_user_meta( (int)$initiator_id, 'notification_friends_friendship_accepted', true ) )
 		return false;
 
 	$ud = get_userdata( $initiator_id );
Index: bp-friends/bp-friends-classes.php
===================================================================
--- bp-friends/bp-friends-classes.php	(revision 2904)
+++ bp-friends/bp-friends-classes.php	(working copy)
@@ -129,7 +129,7 @@
 		if ( !$count )
 			return 0;
 
-		update_usermeta( $user_id, 'total_friend_count', $count );
+		update_user_meta( $user_id, 'total_friend_count', $count );
 		return $count;
 	}
 
Index: bp-activity/bp-activity-filters.php
===================================================================
--- bp-activity/bp-activity-filters.php	(revision 2904)
+++ bp-activity/bp-activity-filters.php	(working copy)
@@ -105,8 +105,8 @@
 			continue;
 
 		/* Increase the number of new @ mentions for the user */
-		$new_mention_count = (int)get_usermeta( $user_id, 'bp_new_mention_count' );
-		update_usermeta( $user_id, 'bp_new_mention_count', $new_mention_count + 1 );
+		$new_mention_count = (int)get_user_meta( $user_id, 'bp_new_mention_count', true );
+		update_user_meta( $user_id, 'bp_new_mention_count', $new_mention_count + 1 );
 
 		$content = str_replace( "@$username", "<a href='" . bp_core_get_user_domain( bp_core_get_userid( $username ) ) . "' rel='nofollow'>@$username</a>", $content );
 	}
Index: bp-activity/bp-activity-notifications.php
===================================================================
--- bp-activity/bp-activity-notifications.php	(revision 2904)
+++ bp-activity/bp-activity-notifications.php	(working copy)
@@ -16,7 +16,7 @@
 			continue;
 
 		// Now email the user with the contents of the message (if they have enabled email notifications)
-		if ( 'no' != get_usermeta( $user_id, 'notification_activity_new_mention' ) ) {
+		if ( 'no' != get_user_meta( $user_id, 'notification_activity_new_mention', true ) ) {
 			$poster_name = bp_core_get_user_displayname( $poster_user_id );
 
 			$message_link = bp_activity_get_permalink( $activity_id );
@@ -60,7 +60,7 @@
 
 	$original_activity = new BP_Activity_Activity( $activity_id );
 
-	if ( $original_activity->user_id != $commenter_id && 'no' != get_usermeta( $original_activity->user_id, 'notification_activity_new_reply' ) ) {
+	if ( $original_activity->user_id != $commenter_id && 'no' != get_user_meta( $original_activity->user_id, 'notification_activity_new_reply', true ) ) {
 		$poster_name = bp_core_get_user_displayname( $commenter_id );
 		$thread_link = bp_activity_get_permalink( $activity_id );
 		$settings_link = bp_core_get_user_domain( $original_activity->user_id ) .  BP_SETTINGS_SLUG . '/notifications/';
@@ -102,7 +102,7 @@
 
 	$parent_comment = new BP_Activity_Activity( $parent_id );
 
-	if ( $parent_comment->user_id != $commenter_id && $original_activity->user_id != $parent_comment->user_id && 'no' != get_usermeta( $parent_comment->user_id, 'notification_activity_new_reply' ) ) {
+	if ( $parent_comment->user_id != $commenter_id && $original_activity->user_id != $parent_comment->user_id && 'no' != get_user_meta( $parent_comment->user_id, 'notification_activity_new_reply', true ) ) {
 		$poster_name = bp_core_get_user_displayname( $commenter_id );
 		$thread_link = bp_activity_get_permalink( $activity_id );
 		$settings_link = bp_core_get_user_domain( $parent_comment->user_id ) .  BP_SETTINGS_SLUG . '/notifications/';
Index: bp-activity/bp-activity-templatetags.php
===================================================================
--- bp-activity/bp-activity-templatetags.php	(revision 2904)
+++ bp-activity/bp-activity-templatetags.php	(working copy)
@@ -25,7 +25,7 @@
 		$this->disable_blogforum_replies = $bp->site_options['bp-disable-blogforum-comments'];
 
 		/* Get an array of the logged in user's favorite activities */
-		$this->my_favs = maybe_unserialize( get_usermeta( $bp->loggedin_user->id, 'bp_favorite_activities' ) );
+		$this->my_favs = get_user_meta( $bp->loggedin_user->id, 'bp_favorite_activities', true );
 
 		if ( !empty( $include ) ) {
 			/* Fetch specific activity items based on ID's */
@@ -728,7 +728,7 @@
 		if ( !$user_id )
 			$user_id = $bp->displayed_user->id;
 
-		if ( !$update = get_usermeta( $user_id, 'bp_latest_update' ) )
+		if ( !$update = get_user_meta( $user_id, 'bp_latest_update', true ) )
 			return false;
 
 		$latest_update = '&quot;' . trim( strip_tags( bp_create_excerpt( $update['content'], 40 ) ) ) . '&quot;';
@@ -830,7 +830,7 @@
 	echo bp_get_total_favorite_count_for_user( $user_id );
 }
 	function bp_get_total_mention_count_for_user( $user_id = false ) {
-		return apply_filters( 'bp_get_total_mention_count_for_user', get_usermeta( $user_id, 'bp_new_mention_count' ) );
+		return apply_filters( 'bp_get_total_mention_count_for_user', get_user_meta( $user_id, 'bp_new_mention_count', true ) );
 	}
 
 function bp_send_public_message_link() {
Index: bp-activity/bp-activity-classes.php
===================================================================
--- bp-activity/bp-activity-classes.php	(revision 2904)
+++ bp-activity/bp-activity-classes.php	(working copy)
@@ -531,10 +531,10 @@
 	function total_favorite_count( $user_id ) {
 		global $bp;
 
-		if ( !$favorite_activity_entries = get_usermeta( $user_id, 'bp_favorite_activities' ) )
+		if ( !$favorite_activity_entries = get_user_meta( $user_id, 'bp_favorite_activities', true ) )
 			return 0;
 
-		return count( maybe_unserialize( $favorite_activity_entries ) );
+		return count( $favorite_activity_entries );
 	}
 
 	function check_exists_by_content( $content ) {
Index: bp-messages.php
===================================================================
--- bp-messages.php	(revision 2904)
+++ bp-messages.php	(working copy)
@@ -175,14 +175,14 @@
 		<tr>
 			<td></td>
 			<td><?php _e( 'A member sends you a new message', 'buddypress' ) ?></td>
-			<td class="yes"><input type="radio" name="notifications[notification_messages_new_message]" value="yes" <?php if ( !get_usermeta( $current_user->id, 'notification_messages_new_message' ) || 'yes' == get_usermeta( $current_user->id, 'notification_messages_new_message' ) ) { ?>checked="checked" <?php } ?>/></td>
-			<td class="no"><input type="radio" name="notifications[notification_messages_new_message]" value="no" <?php if ( 'no' == get_usermeta( $current_user->id, 'notification_messages_new_message' ) ) { ?>checked="checked" <?php } ?>/></td>
+			<td class="yes"><input type="radio" name="notifications[notification_messages_new_message]" value="yes" <?php if ( !get_user_meta( $current_user->id, 'notification_messages_new_message', true ) || 'yes' == get_user_meta( $current_user->id, 'notification_messages_new_message', true ) ) { ?>checked="checked" <?php } ?>/></td>
+			<td class="no"><input type="radio" name="notifications[notification_messages_new_message]" value="no" <?php if ( 'no' == get_user_meta( $current_user->id, 'notification_messages_new_message', true ) ) { ?>checked="checked" <?php } ?>/></td>
 		</tr>
 		<tr>
 			<td></td>
 			<td><?php _e( 'A new site notice is posted', 'buddypress' ) ?></td>
-			<td class="yes"><input type="radio" name="notifications[notification_messages_new_notice]" value="yes" <?php if ( !get_usermeta( $current_user->id, 'notification_messages_new_notice' ) || 'yes' == get_usermeta( $current_user->id, 'notification_messages_new_notice' ) ) { ?>checked="checked" <?php } ?>/></td>
-			<td class="no"><input type="radio" name="notifications[notification_messages_new_notice]" value="no" <?php if ( 'no' == get_usermeta( $current_user->id, 'notification_messages_new_notice' ) ) { ?>checked="checked" <?php } ?>/></td>
+			<td class="yes"><input type="radio" name="notifications[notification_messages_new_notice]" value="yes" <?php if ( !get_user_meta( $current_user->id, 'notification_messages_new_notice', true ) || 'yes' == get_user_meta( $current_user->id, 'notification_messages_new_notice', true ) ) { ?>checked="checked" <?php } ?>/></td>
+			<td class="no"><input type="radio" name="notifications[notification_messages_new_notice]" value="no" <?php if ( 'no' == get_user_meta( $current_user->id, 'notification_messages_new_notice', true ) ) { ?>checked="checked" <?php } ?>/></td>
 		</tr>
 
 		<?php do_action( 'messages_screen_notification_settings' ) ?>
Index: bp-forums.php
===================================================================
--- bp-forums.php	(revision 2904)
+++ bp-forums.php	(working copy)
@@ -500,7 +500,7 @@
 function bp_forums_filter_caps( $allcaps ) {
 	global $bp, $wp_roles, $bb_table_prefix;
 
-	$bb_cap = get_usermeta( $bp->loggedin_user->id, $bb_table_prefix . 'capabilities' );
+	$bb_cap = get_user_meta( $bp->loggedin_user->id, $bb_table_prefix . 'capabilities', true );
 
 	if ( empty( $bb_cap ) )
 		return $allcaps;
Index: bp-groups.php
===================================================================
--- bp-groups.php	(revision 2904)
+++ bp-groups.php	(working copy)
@@ -894,26 +894,26 @@
 		<tr>
 			<td></td>
 			<td><?php _e( 'A member invites you to join a group', 'buddypress' ) ?></td>
-			<td class="yes"><input type="radio" name="notifications[notification_groups_invite]" value="yes" <?php if ( !get_usermeta( $current_user->id, 'notification_groups_invite') || 'yes' == get_usermeta( $current_user->id, 'notification_groups_invite') ) { ?>checked="checked" <?php } ?>/></td>
-			<td class="no"><input type="radio" name="notifications[notification_groups_invite]" value="no" <?php if ( 'no' == get_usermeta( $current_user->id, 'notification_groups_invite') ) { ?>checked="checked" <?php } ?>/></td>
+			<td class="yes"><input type="radio" name="notifications[notification_groups_invite]" value="yes" <?php if ( !get_user_meta( $current_user->id, 'notification_groups_invite', true ) || 'yes' == get_user_meta( $current_user->id, 'notification_groups_invite', true ) ) { ?>checked="checked" <?php } ?>/></td>
+			<td class="no"><input type="radio" name="notifications[notification_groups_invite]" value="no" <?php if ( 'no' == get_user_meta( $current_user->id, 'notification_groups_invite', true ) ) { ?>checked="checked" <?php } ?>/></td>
 		</tr>
 		<tr>
 			<td></td>
 			<td><?php _e( 'Group information is updated', 'buddypress' ) ?></td>
-			<td class="yes"><input type="radio" name="notifications[notification_groups_group_updated]" value="yes" <?php if ( !get_usermeta( $current_user->id, 'notification_groups_group_updated') || 'yes' == get_usermeta( $current_user->id, 'notification_groups_group_updated') ) { ?>checked="checked" <?php } ?>/></td>
-			<td class="no"><input type="radio" name="notifications[notification_groups_group_updated]" value="no" <?php if ( 'no' == get_usermeta( $current_user->id, 'notification_groups_group_updated') ) { ?>checked="checked" <?php } ?>/></td>
+			<td class="yes"><input type="radio" name="notifications[notification_groups_group_updated]" value="yes" <?php if ( !get_user_meta( $current_user->id, 'notification_groups_group_updated', true ) || 'yes' == get_user_meta( $current_user->id, 'notification_groups_group_updated', true ) ) { ?>checked="checked" <?php } ?>/></td>
+			<td class="no"><input type="radio" name="notifications[notification_groups_group_updated]" value="no" <?php if ( 'no' == get_user_meta( $current_user->id, 'notification_groups_group_updated', true ) ) { ?>checked="checked" <?php } ?>/></td>
 		</tr>
 		<tr>
 			<td></td>
 			<td><?php _e( 'You are promoted to a group administrator or moderator', 'buddypress' ) ?></td>
-			<td class="yes"><input type="radio" name="notifications[notification_groups_admin_promotion]" value="yes" <?php if ( !get_usermeta( $current_user->id, 'notification_groups_admin_promotion') || 'yes' == get_usermeta( $current_user->id, 'notification_groups_admin_promotion') ) { ?>checked="checked" <?php } ?>/></td>
-			<td class="no"><input type="radio" name="notifications[notification_groups_admin_promotion]" value="no" <?php if ( 'no' == get_usermeta( $current_user->id, 'notification_groups_admin_promotion') ) { ?>checked="checked" <?php } ?>/></td>
+			<td class="yes"><input type="radio" name="notifications[notification_groups_admin_promotion]" value="yes" <?php if ( !get_user_meta( $current_user->id, 'notification_groups_admin_promotion', true ) || 'yes' == get_user_meta( $current_user->id, 'notification_groups_admin_promotion', true ) ) { ?>checked="checked" <?php } ?>/></td>
+			<td class="no"><input type="radio" name="notifications[notification_groups_admin_promotion]" value="no" <?php if ( 'no' == get_user_meta( $current_user->id, 'notification_groups_admin_promotion', true ) ) { ?>checked="checked" <?php } ?>/></td>
 		</tr>
 		<tr>
 			<td></td>
 			<td><?php _e( 'A member requests to join a private group for which you are an admin', 'buddypress' ) ?></td>
-			<td class="yes"><input type="radio" name="notifications[notification_groups_membership_request]" value="yes" <?php if ( !get_usermeta( $current_user->id, 'notification_groups_membership_request') || 'yes' == get_usermeta( $current_user->id, 'notification_groups_membership_request') ) { ?>checked="checked" <?php } ?>/></td>
-			<td class="no"><input type="radio" name="notifications[notification_groups_membership_request]" value="no" <?php if ( 'no' == get_usermeta( $current_user->id, 'notification_groups_membership_request') ) { ?>checked="checked" <?php } ?>/></td>
+			<td class="yes"><input type="radio" name="notifications[notification_groups_membership_request]" value="yes" <?php if ( !get_user_meta( $current_user->id, 'notification_groups_membership_request', true ) || 'yes' == get_user_meta( $current_user->id, 'notification_groups_membership_request', true ) ) { ?>checked="checked" <?php } ?>/></td>
+			<td class="no"><input type="radio" name="notifications[notification_groups_membership_request]" value="no" <?php if ( 'no' == get_user_meta( $current_user->id, 'notification_groups_membership_request', true ) ) { ?>checked="checked" <?php } ?>/></td>
 		</tr>
 
 		<?php do_action( 'groups_screen_notification_settings' ); ?>
@@ -1564,10 +1564,10 @@
 		return false;
 
 	/* Modify group member count */
-	groups_update_groupmeta( $group_id, 'total_member_count', (int) groups_get_groupmeta( $group_id, 'total_member_count') - 1 );
+	groups_update_groupmeta( $group_id, 'total_member_count', (int) groups_get_groupmeta( $group_id, 'total_member_count' ) - 1 );
 
 	/* Modify user's group memberhip count */
-	update_usermeta( $user_id, 'total_group_count', (int) get_usermeta( $user_id, 'total_group_count') - 1 );
+	update_user_meta( $user_id, 'total_group_count', (int) get_user_meta( $user_id, 'total_group_count', true ) - 1 );
 
 	/* If the user joined this group less than five minutes ago, remove the joined_group activity so
 	 * users cannot flood the activity stream by joining/leaving the group in quick succession.
@@ -2191,7 +2191,7 @@
 	if ( !$member->ban() )
 		return false;
 
-	update_usermeta( $user_id, 'total_group_count', (int)$total_count - 1 );
+	update_user_meta( $user_id, 'total_group_count', (int)$total_count - 1 );
 }
 
 function groups_unban_member( $user_id, $group_id ) {
Index: bp-messages/bp-messages-notifications.php
===================================================================
--- bp-messages/bp-messages-notifications.php	(revision 2904)
+++ bp-messages/bp-messages-notifications.php	(working copy)
@@ -7,7 +7,7 @@
 	$sender_name = bp_core_get_user_displayname( $sender_id );
 
 	foreach( $recipients as $recipient ) {
-		if ( $sender_id == $recipient->user_id || 'no' == get_usermeta( $recipient->user_id, 'notification_messages_new_message' ) ) continue;
+		if ( $sender_id == $recipient->user_id || 'no' == get_user_meta( $recipient->user_id, 'notification_messages_new_message', true ) ) continue;
 
 		$ud = get_userdata( $recipient->user_id );
 		$message_link = bp_core_get_user_domain( $recipient->user_id ) . BP_MESSAGES_SLUG .'/';
Index: bp-messages/bp-messages-templatetags.php
===================================================================
--- bp-messages/bp-messages-templatetags.php	(revision 2904)
+++ bp-messages/bp-messages-templatetags.php	(working copy)
@@ -455,7 +455,7 @@
 	if ( empty( $notice ) )
 		return false;
 
-	$closed_notices = get_usermeta( $userdata->ID, 'closed_notices' );
+	$closed_notices = get_user_meta( $userdata->ID, 'closed_notices', true );
 
 	if ( !$closed_notices )
 		$closed_notices = array();
Index: bp-messages/bp-messages-classes.php
===================================================================
--- bp-messages/bp-messages-classes.php	(revision 2904)
+++ bp-messages/bp-messages-classes.php	(working copy)
@@ -401,7 +401,7 @@
 		// Now deactivate all notices apart from the new one.
 		$wpdb->query( $wpdb->prepare( "UPDATE {$bp->messages->table_name_notices} SET is_active = 0 WHERE id != %d", $id ) );
 
-		update_usermeta( $bp->loggedin_user->id, 'last_activity', date( 'Y-m-d H:i:s' ) );
+		update_user_meta( $bp->loggedin_user->id, 'last_activity', date( 'Y-m-d H:i:s' ) );
 
 		do_action( 'messages_notice_after_save', $this );
 
Index: bp-forums/bp-forums-bbpress.php
===================================================================
--- bp-forums/bp-forums-bbpress.php	(revision 2904)
+++ bp-forums/bp-forums-bbpress.php	(working copy)
@@ -103,7 +103,7 @@
 		/* Set the site admins as the keymasters */
 		$site_admins = get_site_option( 'site_admins', array('admin') );
 		foreach ( (array)$site_admins as $site_admin )
-			update_usermeta( bp_core_get_userid( $site_admin ), $bb_table_prefix . 'capabilities', array( 'keymaster' => true ) );
+			update_user_meta( bp_core_get_userid( $site_admin ), $bb_table_prefix . 'capabilities', array( 'keymaster' => true ) );
 
 		// Create the first forum.
 		bb_new_forum( array( 'forum_name' => 'Default Forum' ) );
@@ -130,7 +130,7 @@
 		$args = wp_parse_args( $args, $defaults );
 		extract( $args, EXTR_SKIP );
 
-		return update_usermeta( $id, $meta_key, $meta_value );
+		return update_user_meta( $id, $meta_key, $meta_value );
 	}
 }
 
Index: bp-groups/bp-groups-classes.php
===================================================================
--- bp-groups/bp-groups-classes.php	(revision 2904)
+++ bp-groups/bp-groups-classes.php	(working copy)
@@ -742,9 +742,9 @@
 
 		groups_update_groupmeta( $this->group_id, 'total_member_count', ( (int) groups_get_groupmeta( $this->group_id, 'total_member_count' ) - 1 ) );
 
-		$group_count = get_usermeta( $this->user_id, 'total_group_count' );
+		$group_count = get_user_meta( $this->user_id, 'total_group_count', true );
 		if ( !empty( $group_count ) )
-			update_usermeta( $this->user_id, 'total_group_count', (int)$group_count - 1 );
+			update_user_meta( $this->user_id, 'total_group_count', (int)$group_count - 1 );
 
 		return $this->save();
 	}
@@ -756,7 +756,7 @@
 		$this->is_banned = 0;
 
 		groups_update_groupmeta( $this->group_id, 'total_member_count', ( (int) groups_get_groupmeta( $this->group_id, 'total_member_count' ) + 1 ) );
-		update_usermeta( $this->user_id, 'total_group_count', (int)get_usermeta( $this->user_id, 'total_group_count' ) + 1 );
+		update_user_meta( $this->user_id, 'total_group_count', (int)get_user_meta( $this->user_id, 'total_group_count', true ) + 1 );
 
 		return $this->save();
 	}
Index: bp-groups/bp-groups-notifications.php
===================================================================
--- bp-groups/bp-groups-notifications.php	(revision 2904)
+++ bp-groups/bp-groups-notifications.php	(working copy)
@@ -8,7 +8,7 @@
 
 	$user_ids = BP_Groups_Member::get_group_member_ids( $group->id );
 	foreach ( (array)$user_ids as $user_id ) {
-		if ( 'no' == get_usermeta( $user_id, 'notification_groups_group_updated' ) ) continue;
+		if ( 'no' == get_user_meta( $user_id, 'notification_groups_group_updated', true ) ) continue;
 
 		$ud = bp_core_get_core_userdata( $user_id );
 
@@ -44,7 +44,7 @@
 
 	bp_core_add_notification( $requesting_user_id, $admin_id, 'groups', 'new_membership_request', $group_id );
 
-	if ( 'no' == get_usermeta( $admin_id, 'notification_groups_membership_request' ) )
+	if ( 'no' == get_user_meta( $admin_id, 'notification_groups_membership_request', true ) )
 		return false;
 
 	$requesting_user_name = bp_core_get_user_displayname( $requesting_user_id );
@@ -93,7 +93,7 @@
 	else
 		bp_core_add_notification( $group_id, $requesting_user_id, 'groups', 'membership_request_rejected' );
 
-	if ( 'no' == get_usermeta( $requesting_user_id, 'notification_membership_request_completed' ) )
+	if ( 'no' == get_user_meta( $requesting_user_id, 'notification_membership_request_completed', true ) )
 		return false;
 
 	$group = new BP_Groups_Group( $group_id );
@@ -151,7 +151,7 @@
 	// Post a screen notification first.
 	bp_core_add_notification( $group_id, $user_id, 'groups', $type );
 
-	if ( 'no' == get_usermeta( $user_id, 'notification_groups_admin_promotion' ) )
+	if ( 'no' == get_user_meta( $user_id, 'notification_groups_admin_promotion', true ) )
 		return false;
 
 	$group = new BP_Groups_Group( $group_id );
@@ -199,7 +199,7 @@
 		// Post a screen notification first.
 		bp_core_add_notification( $group->id, $invited_user_id, 'groups', 'group_invite' );
 
-		if ( 'no' == get_usermeta( $invited_user_id, 'notification_groups_invite' ) )
+		if ( 'no' == get_user_meta( $invited_user_id, 'notification_groups_invite', true ) )
 			return false;
 
 		$invited_ud = bp_core_get_core_userdata($invited_user_id);
@@ -258,7 +258,7 @@
 			continue;
 
 		// Now email the user with the contents of the message (if they have enabled email notifications)
-		if ( 'no' != get_usermeta( $user_id, 'notification_activity_new_mention' ) ) {
+		if ( 'no' != get_user_meta( $user_id, 'notification_activity_new_mention', true ) ) {
 			$poster_name = bp_core_get_user_displayname( $poster_user_id );
 
 			$message_link = bp_activity_get_permalink( $activity_id );

Index: bp-core/bp-core-classes.php
===================================================================
--- bp-core/bp-core-classes.php	(revision 2904)
+++ bp-core/bp-core-classes.php	(working copy)
@@ -50,7 +50,7 @@
 	 * @uses bp_core_get_userurl() Returns the URL with no HTML markup for a user based on their user id
 	 * @uses bp_core_get_userlink() Returns a HTML formatted link for a user with the user's full name as the link text
 	 * @uses bp_core_get_user_email() Returns the email address for the user based on user ID
 	 * @uses get_usermeta() WordPress function returns the value of passed usermeta name from usermeta table
 	 * @uses bp_core_fetch_avatar() Returns HTML formatted avatar for a user
 	 * @uses bp_profile_last_updated_date() Returns the last updated date for a user.
 	 */
@@ -79,7 +79,7 @@
 		$this->avatar_thumb = bp_core_fetch_avatar( array( 'item_id' => $this->id, 'type' => 'thumb' ) );
 		$this->avatar_mini = bp_core_fetch_avatar( array( 'item_id' => $this->id, 'type' => 'thumb', 'width' => 30, 'height' => 30 ) );
 
-		$this->last_active = bp_core_get_last_activity( get_usermeta( $this->id, 'last_activity' ), __( 'active %s ago', 'buddypress' ) );
+		$this->last_active = bp_core_get_last_activity( get_user_meta( $this->id, 'last_activity', true ), __( 'active %s ago', 'buddypress' ) );
 	}
 
 	function populate_extras() {
@@ -50,7 +50,7 @@
 	 * @uses bp_core_get_userlink() Returns a HTML formatted link for a user with the user's full name as the link text
 	 * @uses bp_core_get_user_email() Returns the email address for the user based on user ID
-	 * @uses get_usermeta() WordPress function returns the value of passed usermeta name from usermeta table
+	 * @uses get_user_meta() WordPress function returns the value of passed usermeta name from usermeta table
 	 * @uses bp_core_fetch_avatar() Returns HTML formatted avatar for a user
 	 * @uses bp_profile_last_updated_date() Returns the last updated date for a user.
Index: bp-core.php
===================================================================
--- bp-core.php	(revision 2904)
+++ bp-core.php	(working copy)
@@ -513,7 +513,7 @@
  * @package BuddyPress Core
  * @global $current_user WordPress global variable containing current logged in user information
  * @param user_id The ID of the user.
  * @uses get_usermeta() WordPress function to get the usermeta for a user.
  */
 function bp_core_get_user_domain( $user_id, $user_nicename = false, $user_login = false ) {
 	global $bp;
@@ -1384,7 +1384,7 @@
  *
  * @package BuddyPress Core
  * @global $userdata WordPress user data for the current logged in user.
  * @uses update_usermeta() WordPress function to update user metadata in the usermeta table.
  */
 function bp_core_record_activity() {
 	global $bp;
@@ -1392,13 +1392,13 @@
 	if ( !is_user_logged_in() )
 		return false;
 
-	$activity = get_usermeta( $bp->loggedin_user->id, 'last_activity' );
+	$activity = get_user_meta( $bp->loggedin_user->id, 'last_activity', true );
 
 	if ( !is_numeric( $activity ) )
 		$activity = strtotime( $activity );
 
 	if ( '' == $activity || strtotime( gmdate( "Y-m-d H:i:s" ) ) >= strtotime( '+5 minutes', $activity ) )
-		update_usermeta( $bp->loggedin_user->id, 'last_activity', gmdate( "Y-m-d H:i:s" ) );
+		update_user_meta( $bp->loggedin_user->id, 'last_activity', gmdate( "Y-m-d H:i:s" ) );
 }
 add_action( 'wp_head', 'bp_core_record_activity' );
 
@@ -1825,11 +1825,11 @@
  *
  * @package BuddyPress Core
  * @param $user_id The user id for the user to delete usermeta for
  * @uses delete_usermeta() deletes a row from the wp_usermeta table based on meta_key
  */
 function bp_core_remove_data( $user_id ) {
 	/* Remove usermeta */
-	delete_usermeta( $user_id, 'last_activity' );
+	delete_user_meta( $user_id, 'last_activity' );
 
 	/* Flush the cache to remove the user from all cached objects */
 	wp_cache_flush();
@@ -513,7 +513,7 @@
  * @global $current_user WordPress global variable containing current logged in user information
  * @param user_id The ID of the user.
- * @uses get_usermeta() WordPress function to get the usermeta for a user.
+ * @uses get_user_meta() WordPress function to get the usermeta for a user.
  */
 function bp_core_get_user_domain( $user_id, $user_nicename = false, $user_login = false ) {
@@ -1384,7 +1384,7 @@
  * @package BuddyPress Core
  * @global $userdata WordPress user data for the current logged in user.
- * @uses update_usermeta() WordPress function to update user metadata in the usermeta table.
+ * @uses update_user_meta() WordPress function to update user metadata in the usermeta table.
  */
 function bp_core_record_activity() {
@@ -1825,11 +1825,11 @@
  * @package BuddyPress Core
  * @param $user_id The user id for the user to delete usermeta for
- * @uses delete_usermeta() deletes a row from the wp_usermeta table based on meta_key
+ * @uses delete_user_meta() deletes a row from the wp_usermeta table based on meta_key
  */
 function bp_core_remove_data( $user_id ) {
Index: bp-xprofile.php
===================================================================
--- bp-xprofile.php	(revision 2904)
+++ bp-xprofile.php	(working copy)
@@ -838,9 +838,9 @@
 		$lastname = trim( substr( $fullname, $space, strlen($fullname) ) );
 	}
 
-	update_usermeta( $user_id, 'nickname', $fullname );
-	update_usermeta( $user_id, 'first_name', $firstname );
-	update_usermeta( $user_id, 'last_name', $lastname );
+	update_user_meta( $user_id, 'nickname', $fullname );
+	update_user_meta( $user_id, 'first_name', $firstname );
+	update_user_meta( $user_id, 'last_name', $lastname );
 
 	$wpdb->query( $wpdb->prepare( "UPDATE {$wpdb->users} SET display_name = %s WHERE ID = %d", $fullname, $user_id ) );
 	$wpdb->query( $wpdb->prepare( "UPDATE {$wpdb->users} SET user_url = %s WHERE ID = %d", bp_core_get_user_domain( $user_id ), $user_id ) );
@@ -874,22 +874,22 @@
  *
  * @package BuddyPress XProfile
  * @param $user_id The ID of the deleted user
  * @uses get_usermeta() Get a user meta value based on meta key from wp_usermeta
  * @uses delete_usermeta() Delete user meta value based on meta key from wp_usermeta
  * @uses delete_data_for_user() Removes all profile data from the xprofile tables for the user
  */
 function xprofile_remove_data( $user_id ) {
 	BP_XProfile_ProfileData::delete_data_for_user( $user_id );
 
 	/* delete any avatar files. */
-	@unlink( get_usermeta( $user_id, 'bp_core_avatar_v1_path' ) );
-	@unlink( get_usermeta( $user_id, 'bp_core_avatar_v2_path' ) );
+	@unlink( get_user_meta( $user_id, 'bp_core_avatar_v1_path', true ) );
+	@unlink( get_user_meta( $user_id, 'bp_core_avatar_v2_path', true ) );
 
 	/* unset the usermeta for avatars from the usermeta table. */
-	delete_usermeta( $user_id, 'bp_core_avatar_v1' );
-	delete_usermeta( $user_id, 'bp_core_avatar_v1_path' );
-	delete_usermeta( $user_id, 'bp_core_avatar_v2' );
-	delete_usermeta( $user_id, 'bp_core_avatar_v2_path' );
+	delete_user_meta( $user_id, 'bp_core_avatar_v1' );
+	delete_user_meta( $user_id, 'bp_core_avatar_v1_path' );
+	delete_user_meta( $user_id, 'bp_core_avatar_v2' );
+	delete_user_meta( $user_id, 'bp_core_avatar_v2_path' );
 }
 add_action( 'wpmu_delete_user', 'xprofile_remove_data', 1 );
 add_action( 'delete_user', 'xprofile_remove_data', 1 );
@@ -874,22 +874,22 @@
  * @package BuddyPress XProfile
  * @param $user_id The ID of the deleted user
- * @uses get_usermeta() Get a user meta value based on meta key from wp_usermeta
- * @uses delete_usermeta() Delete user meta value based on meta key from wp_usermeta
+ * @uses get_user_meta() Get a user meta value based on meta key from wp_usermeta
+ * @uses delete_user_meta() Delete user meta value based on meta key from wp_usermeta
  * @uses delete_data_for_user() Removes all profile data from the xprofile tables for the user
  */